import React from 'react';

import { Select } from '../../../select';

import { useStyles } from './styles';

const CANADA_STATES = [
    { value: 'AB', displayValue: 'Alberta' },
    { value: 'BC', displayValue: 'British Columbia' },
    { value: 'MB', displayValue: 'Manitoba' },
    { value: 'NB', displayValue: 'New Brunswick' },
    { value: 'NL', displayValue: 'Newfoundland And Labrador' },
    { value: 'NT', displayValue: 'Northwest Territories' },
    { value: 'NS', displayValue: 'Nova Scotia' },
    { value: 'NU', displayValue: 'Nunavut' },
    { value: 'ON', displayValue: 'Ontario' },
    { value: 'PE', displayValue: 'Prince Edward Island' },
    { value: 'QC', displayValue: 'Quebec' },
    { value: 'SK', displayValue: 'Saskatchewan' },
    { value: 'YT', displayValue: 'Yukon' },
];

type CanadaStateOrProvinceProps = { stateOrProvince: string, handleChangeStateOrProvince: (target: any) => void };

const getDisplayValue = (value: string) => CANADA_STATES.find(s => s.value === value)?.displayValue;

export const CanadaStateOrProvince = ({ stateOrProvince, handleChangeStateOrProvince }: CanadaStateOrProvinceProps) => {
    const { rootClass } = useStyles();

    if (!stateOrProvince) {
        handleChangeStateOrProvince({ target: CANADA_STATES[0] });
    }

    const displayValue = getDisplayValue(stateOrProvince) || '';

    return (
        <Select
            rootClassName={rootClass}
            onChange={handleChangeStateOrProvince}
            value={{value: stateOrProvince, displayValue}}
            placeholder="Province"
            options={CANADA_STATES}
        />
    )
}
